Package: RCarb
Type: Package
Title: Dose Rate Modelling of Carbonate-Rich Samples
Version: 0.1.8
Date: 2026-05-12
Authors@R: c(
    person("Sebastian", "Kreutzer", role = c("aut", "trl", "cre", "dtc"), 
     email = "sebastian.kreutzer@uni-heidelberg.de",
     comment = c(ORCID = "0000-0002-0734-2199")),
    person("Roger P.", "Nathan", role = c("aut", "cph")),
    person("Barbara", "Mauz", role = c("aut", "cph"), comment = c(ORCID = "0000-0003-1504-333X")))
Maintainer: Sebastian Kreutzer <sebastian.kreutzer@uni-heidelberg.de>
Description: Translation of the 'MATLAB' program 'Carb' (Nathan and Mauz 2008 <DOI:10.1016/j.radmeas.2007.12.012>; Mauz and Hoffmann 2014) for dose rate modelling for carbonate-rich samples in the context of trapped charged dating (e.g., luminescence dating) applications. 
Depends: R (>= 4.5), utils
Imports: interp (>= 1.1), matrixStats (>= 1.5.0), parallel (>= 1.0.17)
Suggests: testthat (>= 3.3.2), R.rsp (>= 0.46.0)
URL: https://r-lum.github.io/RCarb/
BugReports: https://github.com/R-Lum/RCarb/issues
License: GPL-3
Encoding: UTF-8
Language: en-GB
LazyData: true
VignetteBuilder: R.rsp
Config/testthat/edition: 3
Config/testthat/parallel: true
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-05-12 15:13:56 UTC; kreutzer
Author: Sebastian Kreutzer [aut, trl, cre, dtc] (ORCID:
    <https://orcid.org/0000-0002-0734-2199>),
  Roger P. Nathan [aut, cph],
  Barbara Mauz [aut, cph] (ORCID:
    <https://orcid.org/0000-0003-1504-333X>)
Repository: CRAN
Date/Publication: 2026-05-12 16:00:02 UTC
