# Generated by roxygen2: do not edit by hand

export(model_DoseRate)
export(write_InputTemplate)
import(utils)
importFrom(grDevices,rgb)
importFrom(graphics,abline)
importFrom(graphics,axis)
importFrom(graphics,lines)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,plot.default)
importFrom(graphics,points)
importFrom(graphics,polygon)
importFrom(graphics,text)
importFrom(stats,approx)
importFrom(stats,density)
importFrom(stats,na.exclude)
importFrom(stats,nlminb)
importFrom(stats,rnorm)
importFrom(stats,sd)
